---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

### Subject of the issue
Describe your issue here.

### Your environment
- OS: [e.g. iOS]
- Python version: [e.g. 3.7.2]
- Package Version [e.g. 0.1.2]
- Anything else you consider helpful.

### Steps to reproduce
Tell us how to reproduce this issue.

### Expected behaviour
Tell us what should happen

### Actual behaviour
Tell us what happens instead
